@@ -611,14 +611,14 @@ class DataTransform(forms.ModelForm):
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
-            queryset=self.instance.datatransformerconstants_set,
+            queryset=self.instance.data_transformer_constants,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id) + 'DataConstantsTransformerInlineFormset',
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count()
+        self.nested_constants_form.extra = self.instance.data_transformer_constants.count()
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
@@ -760,14 +760,14 @@ class DataTransformRoot(forms.ModelForm):
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
-            queryset=self.instance.datatransformerconstants_set,
+            queryset=self.instance.data_transformer_constants,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id) + 'DataConstantsTransformerInlineFormset',
             initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
-        self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count()
+        self.nested_constants_form.extra = self.instance.data_transformer_constants.count()
 
         hardware_outputs = self.instance.hardwaredatatransformer_set.first()
         self.nested_hardware_outputs_form = HardwareTransformerForm(
