@@ -222,7 +222,7 @@ class DataTransformerConstantsSerializer(serializers.ModelSerializer):
 
 
 class DataTransformerTreeSerializer(serializers.ModelSerializer):
-    datatransformerconstants = DataTransformerConstantsSerializer(many=True)
+    data_transformer_constants = DataTransformerConstantsSerializer(many=True)
     children = serializers.SerializerMethodField(source='get_children')
     class Meta:
         model=DataTransformer
